@@ -3,6 +3,7 @@ use crate::{column_default, Column};
 use dockworker::container::ContainerFilters;
 use std::cmp;
 use std::collections::HashMap;
+use tokio::runtime::Runtime;
 
 pub struct Docker {
     header: String,
@@ -25,7 +26,10 @@ impl Docker {
         let mut containers = HashMap::new();
         let mut available = true;
         if let Ok(docker) = dockworker::Docker::connect_with_unix(path) {
-            if let Ok(cont) = docker.list_containers(None, None, None, ContainerFilters::new()) {
+            let rt = Runtime::new().unwrap();
+            if let Ok(cont) =
+                rt.block_on(docker.list_containers(None, None, None, ContainerFilters::new()))
+            {
                 for c in cont {
                     // remove the first letter '/' from container name
                     let name = String::from(&c.Names[0][1..]);
@@ -58,11 +62,14 @@ impl Docker {
         let mut containers = HashMap::new();
         let mut available = true;
         if let Ok(docker) = dockworker::Docker::connect_with_unix(path) {
-            if let Ok(cont) = docker.list_containers(None, None, None, ContainerFilters::new()) {
+            let rt = Runtime::new().unwrap();
+            if let Ok(cont) =
+                rt.block_on(docker.list_containers(None, None, None, ContainerFilters::new()))
+            {
                 for c in cont {
                     // remove the first letter '/' from container name
                     let name = String::from(&c.Names[0][1..]);
-                    if let Ok(processes) = docker.processes(c.Id.as_str()) {
+                    if let Ok(processes) = rt.block_on(docker.processes(c.Id.as_str())) {
                         for p in processes {
                             if let Ok(pid) = p.pid.parse::<i32>() {
                                 containers.insert(pid, name.clone());
