@@ -14,7 +14,7 @@ pub struct Tty {
 impl Tty {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("TTY"));
-        let unit = String::from("");
+        let unit = String::new();
         Tty {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
@@ -30,9 +30,9 @@ impl Column for Tty {
     fn add(&mut self, proc: &ProcessInfo) {
         let (major, minor) = proc.curr_proc.stat().tty_nr();
         let fmt_content = if major == 136 {
-            format!("pts/{}", minor)
+            format!("pts/{minor}")
         } else {
-            String::from("")
+            String::new()
         };
         let raw_content = fmt_content.clone();
 
