@@ -168,7 +168,11 @@ impl View {
             config.display.show_thread
         };
 
-        let proc = collect_proc(Duration::from_millis(opt.interval), show_thread);
+        let proc = collect_proc(
+            Duration::from_millis(opt.interval),
+            show_thread,
+            config.display.show_kthreads,
+        );
         for c in columns.iter_mut() {
             for p in &proc {
                 c.column.add(p);
@@ -188,7 +192,7 @@ impl View {
             }
         }
 
-        let term_info = TermInfo::new(clear_by_line, false);
+        let term_info = TermInfo::new(clear_by_line, false)?;
         let mut sort_info = View::get_sort_info(opt, config, &columns);
 
         if opt.only.is_some() {
